PermissionManagerPermission enum
Defines the various permissions that can be managed.
Values
- camera → const PermissionManagerPermission
-
Access to the device's camera.
- microphone → const PermissionManagerPermission
-
Access to the device's microphone.
- location → const PermissionManagerPermission
-
Access to the device's location.
- locationAlways → const PermissionManagerPermission
-
Access to the device's location even when the app is in the background.
- storage → const PermissionManagerPermission
-
Access to the device's external storage.
- photos → const PermissionManagerPermission
-
Access to the device's photo library.
- notifications → const PermissionManagerPermission
-
Sending notifications to the user.
- contacts → const PermissionManagerPermission
-
Access to the device's contacts.
- phone → const PermissionManagerPermission
-
Access to the device's phone state and features.
- ignoreBatteryOptimizations → const PermissionManagerPermission
-
Android specific: Request to ignore battery optimizations.
- systemAlertWindow → const PermissionManagerPermission
-
Android specific: Request to draw over other apps.
- scheduleExactAlarm → const PermissionManagerPermission
-
Android specific: Request to schedule exact alarms.
- mediaImages → const PermissionManagerPermission
-
Android 13+ Media: Access to video files.
- mediaVideo → const PermissionManagerPermission
-
Android 13+ Media: Access to video files.
- mediaAudio → const PermissionManagerPermission
-
Android 13+ Media: Access to audio files.
- bluetooth → const PermissionManagerPermission
-
Access to Bluetooth features.
- bluetoothScan → const PermissionManagerPermission
-
Access to scanning for nearby Bluetooth devices.
- bluetoothConnect → const PermissionManagerPermission
-
Access to connecting with paired Bluetooth devices.
- bluetoothAdvertise → const PermissionManagerPermission
-
Access to advertising the device to other Bluetooth devices.
- nearbyDevices → const PermissionManagerPermission
-
Access to scanning for nearby devices using Bluetooth, Wi-Fi, or other technologies.
- calendar → const PermissionManagerPermission
-
Access to the device's calendar.
- sms → const PermissionManagerPermission
-
Access to the device's SMS features.
- sendSms → const PermissionManagerPermission
-
Permission to send SMS messages.
- activityRecognition → const PermissionManagerPermission
-
Access to activity recognition data.
- accessMediaLocation → const PermissionManagerPermission
-
Access to the location of media files.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
PermissionManagerPermission> - A constant List of the values in this enum, in order of their declaration.